# Security Policy

## Supported Versions

| Version |     Supported      |
|:-------:|:------------------:|
|   2.x   | :white_check_mark: |
|   1.x   |        :x:         |

## Reporting a Vulnerability

If you believe you have found a security vulnerability in this repository, please report it to me through coordinated
disclosure.

**Please do not report security vulnerabilities through public GitHub issues, discussions, or pull requests.**

Instead, please email to xjasonlyu[@]gmail.com.

Please include as much of the information listed below as you can to help me better understand and resolve the issue:

* The type of issue (e.g., buffer overflow, payload attack)
* Full paths of source file(s) related to the manifestation of the issue
* The location of the affected source code (tag/branch/commit or direct URL)
* Any special configuration required to reproduce the issue
* Step-by-step instructions to reproduce the issue
* Proof-of-concept or exploit code (if possible)
* Impact of the issue, including how an attacker might exploit the issue

This information will help me triage your report more quickly.
